@@ -166,6 +166,12 @@ class ConfigMetaTypeProvider implements MetaTypeProvider
                 -1,
                 bundle.getBundleContext().getProperty(JettyConfig.FELIX_JETTY_THREADPOOL_MAX)));
 
+        adList.add(new AttributeDefinitionImpl(JettyConfig.FELIX_JETTY_USE_VIRTUAL_THREADS,
+                "Use Virtual Threads",
+                "Use virtual threads in Jetty (JDK 21 or higher). Defaults to false.",
+                -1,
+                bundle.getBundleContext().getProperty(JettyConfig.FELIX_JETTY_USE_VIRTUAL_THREADS)));
+
         adList.add(new AttributeDefinitionImpl(JettyConfig.FELIX_JETTY_ACCEPTORS,
                 "Acceptors",
                 "Number of acceptor threads to use, or -1 for a default value. Acceptors accept new TCP/IP connections. If 0, then the selector threads are used to accept connections.",
@@ -197,11 +203,29 @@ class ConfigMetaTypeProvider implements MetaTypeProvider
                 bundle.getBundleContext().getProperty(JettyConfig.FELIX_JETTY_RESPONSE_BUFFER_SIZE)));
 
         adList.add(new AttributeDefinitionImpl(JettyConfig.FELIX_JETTY_MAX_FORM_SIZE,
-                "Maximum Form Size",
+                "Maximum Form Size in bytes",
                 "Size of Body for submitted form content. Default is 200KB.",
                 204800,
                 bundle.getBundleContext().getProperty(JettyConfig.FELIX_JETTY_MAX_FORM_SIZE)));
 
+        adList.add(new AttributeDefinitionImpl(JettyConfig.FELIX_JETTY_REQUEST_SIZE_LIMIT,
+                "Maximum request size in bytes",
+                "Maximum size of the request body in bytes. Default is unlimited.",
+                204800,
+                bundle.getBundleContext().getProperty(JettyConfig.FELIX_JETTY_REQUEST_SIZE_LIMIT)));
+
+        adList.add(new AttributeDefinitionImpl(JettyConfig.FELIX_JETTY_RESPONSE_SIZE_LIMIT,
+                "Maximum response size in bytes",
+                "Maximum size of the response body in bytes. Default is unlimited.",
+                204800,
+                bundle.getBundleContext().getProperty(JettyConfig.FELIX_JETTY_RESPONSE_SIZE_LIMIT)));
+
+        adList.add(new AttributeDefinitionImpl(JettyConfig.FELIX_JETTY_ERROR_PAGE_CUSTOM_HEADERS,
+                "Custom headers to add to error pages",
+                "Felix specific property to configure the custom headers to add to all error pages served by Jetty. Separate key-value pairs with ##.",
+                null,
+                bundle.getBundleContext().getProperty(JettyConfig.FELIX_JETTY_ERROR_PAGE_CUSTOM_HEADERS)));
+
         adList.add(new AttributeDefinitionImpl(JettyConfig.FELIX_HTTP_PATH_EXCLUSIONS,
                 "Path Exclusions",
                 "Contains a list of context path prefixes. If a Web Application Bundle is started with a context path matching any " +
@@ -284,6 +308,12 @@ class ConfigMetaTypeProvider implements MetaTypeProvider
                 false,
                 bundle.getBundleContext().getProperty(JettyConfig.FELIX_JETTY_SESSION_COOKIE_SECURE)));
 
+        adList.add(new AttributeDefinitionImpl(JettyConfig.FELIX_JETTY_URI_COMPLIANCE_MODE,
+                "Jetty URI compliance mode",
+                "Jetty URI compliance mode (if not set, Jetty will configure a default)",
+                null,
+                bundle.getBundleContext().getProperty(JettyConfig.FELIX_JETTY_URI_COMPLIANCE_MODE)));
+
         adList.add(new AttributeDefinitionImpl(JettyConfig.FELIX_JETTY_SERVLET_SESSION_ID_PATH_PARAMETER_NAME,
                 "Session Id path parameter",
                 "Defaults to jsessionid. If set to null or \"none\" no URL rewriting will be done.",
@@ -483,6 +513,23 @@ class ConfigMetaTypeProvider implements MetaTypeProvider
                 "The format of the request log entries. Only relevant if 'Enable SLF4J Request Logging' is checked. Valid placeholders are described in https://www.eclipse.org/jetty/documentation/jetty-11/operations-guide/index.html#og-module-requestlog",
                 CustomRequestLog.NCSA_FORMAT,
                 bundle.getBundleContext().getProperty(JettyConfig.FELIX_HTTP_REQUEST_LOG_FORMAT)));
+
+        adList.add(new AttributeDefinitionImpl(JettyConfig.FELIX_JAKARTA_WEBSOCKET_ENABLE,
+                "Enable Jakarta standard WebSocket support",
+                "Whether to enable jakarta standard WebSocket support. Default is false.",
+                false,
+                bundle.getBundleContext().getProperty(JettyConfig.FELIX_JAKARTA_WEBSOCKET_ENABLE)));
+        adList.add(new AttributeDefinitionImpl(JettyConfig.FELIX_JETTY_WEBSOCKET_ENABLE,
+                "Enable Jetty specific WebSocket support",
+                "Whether to enable jetty specific WebSocket support. Default is false.",
+                false,
+                bundle.getBundleContext().getProperty(JettyConfig.FELIX_JETTY_WEBSOCKET_ENABLE)));
+        adList.add(new AttributeDefinitionImpl(JettyConfig.FELIX_JETTY_ALLOW_RELATIVE_REDIRECTS,
+                "Allow Relative Redirects",
+                "Whether or not relative redirects are allowed. Defaults to true thus relative redirects are allowed.",
+                true,
+                bundle.getBundleContext().getProperty(JettyConfig.FELIX_JETTY_ALLOW_RELATIVE_REDIRECTS)));
+
         return new ObjectClassDefinition()
         {
 
